==> exaile-0.3.0.1p0.tgz: lib/python2.5/site-packages/exaile/xl/metadata/sid.py <==
# Copyright (C) 2008-2009 Adam Olsen 
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#
# The developers of the Exaile media player hereby grant permission 
# for non-GPL compatible GStreamer and Exaile plugins to be used and 
# distributed together with GStreamer and Exaile. This permission is 
# above and beyond the permissions granted by the GPL license by which 
# Exaile is covered. If you modify this code, you may extend this 
# exception to your version of the code, but you are not obligated to 
# do so. If you do not wish to do so, delete this exception statement 
# from your version.

from xl.metadata import BaseFormat
from mutagen import FileType

class SidFormat(BaseFormat):
    MutagenType = FileType #not actually used

    def load(self):
        f = open(self.loc, "rb")
        f.seek(22)
        data = {}
        data['title'] = f.read(32).replace(chr(0), "")
        data['artist'] = f.read(32).replace(chr(0), "")
        data['copyright'] = f.read(32).replace(chr(0), "")
        f.close()
        self.mutagen = data

    def get_length(self):
        return -1

    def get_bitrate(self):
        return -1

==> exaile-0.3.1.2.tgz: lib/python2.5/site-packages/exaile/xl/metadata/sid.py <==
# Copyright (C) 2008-2009 Adam Olsen
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
#
# The developers of the Exaile media player hereby grant permission
# for non-GPL compatible GStreamer and Exaile plugins to be used and
# distributed together with GStreamer and Exaile. This permission is
# above and beyond the permissions granted by the GPL license by which
# Exaile is covered. If you modify this code, you may extend this
# exception to your version of the code, but you are not obligated to
# do so. If you do not wish to do so, delete this exception statement
# from your version.



from xl.metadata._base import BaseFormat
from mutagen import FileType

class SidFormat(BaseFormat):
    writable = False

    def load(self):
        f = open(self.loc, "rb")
        f.seek(22)
        data = {}
        data['title'] = f.read(32).replace(chr(0), "")
        data['artist'] = f.read(32).replace(chr(0), "")
        data['copyright'] = f.read(32).replace(chr(0), "")
        f.close()
        self.mutagen = data

    def get_length(self):
        return -1

    def get_bitrate(self):
        return -1
